#
# spec file for package dirac
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dirac
Version:        1.0.2
Release:        lp152.3.9
Summary:        The Dirac_Video Codec
License:        MPL-1.1
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            https://sourceforge.net/projects/dirac/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         0001-Fix-uninitialised-memory-read-that-causes-the-encode.patch
Patch1:         %{name}-%{version}-gcc45.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cppunit)

%description
Dirac is an open source video codec. It uses a traditional hybrid video
codec architecture, but with the wavelet transform instead of the usual
block transforms.  Motion compensation uses overlapped blocks to reduce
block artefacts that would upset the transform coding stage.

Dirac can code just about any size of video, from streaming up to HD
and beyond, although certain presets are defined for different
applications and standards.  These cover the parameters that need to be
set for the encoder to work, such as block sizes and temporal
prediction structures, which must otherwise be set by hand.

%package -n libdirac_decoder0
Summary:        Dirac Video Codec Decoder Library
Group:          System/Libraries

%description -n libdirac_decoder0
Dirac is an open source video codec. It uses a traditional hybrid video
codec architecture, but with the wavelet transform instead of the usual
block transforms.  Motion compensation uses overlapped blocks to reduce
block artefacts that would upset the transform coding stage.

Dirac can code just about any size of video, from streaming up to HD
and beyond, although certain presets are defined for different
applications and standards.  These cover the parameters that need to be
set for the encoder to work, such as block sizes and temporal
prediction structures, which must otherwise be set by hand.

%package -n libdirac_encoder0
Summary:        Dirac Video Codec Encoder Library
Group:          System/Libraries

%description -n libdirac_encoder0
Dirac is an open source video codec. It uses a traditional hybrid video
codec architecture, but with the wavelet transform instead of the usual
block transforms.  Motion compensation uses overlapped blocks to reduce
block artefacts that would upset the transform coding stage.

Dirac can code just about any size of video, from streaming up to HD
and beyond, although certain presets are defined for different
applications and standards.  These cover the parameters that need to be
set for the encoder to work, such as block sizes and temporal
prediction structures, which must otherwise be set by hand.

%package devel
Summary:        Development Files for Dirac Video Codec
Group:          Development/Libraries/C and C++
Requires:       libdirac_decoder0 = %{version}
Requires:       libdirac_encoder0 = %{version}
Provides:       libdirac-devel = %{version}-%{release}
Obsoletes:      libdirac-devel < %{version}-%{release}

%description devel
Dirac is an open source video codec. It uses a traditional hybrid video
codec architecture, but with the wavelet transform instead of the usual
block transforms.  Motion compensation uses overlapped blocks to reduce
block artefacts that would upset the transform coding stage.

Dirac can code just about any size of video, from streaming up to HD
and beyond, although certain presets are defined for different
applications and standards.  These cover the parameters that need to be
set for the encoder to work, such as block sizes and temporal
prediction structures, which must otherwise be set by hand.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
# Code is not mature enough for -Werror (unused results)
sed -i 's/-Werror//' configure.ac

%build
ACLOCAL="aclocal -I m4" autoreconf -fvi
%configure \
	--disable-silent-rules \
	--disable-static \
	--docdir=%{_docdir}/packages/%{name} \
	--enable-mmx \
	--enable-overlay
make %{?_smp_mflags}

%install
%make_install htmldir=%{_docdir}/%{name}/code/api_html
# remove the docs we want with main pkg
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_docdir}/%{name}

%post -n libdirac_decoder0 -p /sbin/ldconfig
%postun -n libdirac_decoder0 -p /sbin/ldconfig
%post -n libdirac_encoder0 -p /sbin/ldconfig
%postun -n libdirac_encoder0 -p /sbin/ldconfig

%files
%doc AUTHORS COPYING ChangeLog NEWS README TODO
%{_bindir}/*

%files -n libdirac_decoder0
%{_libdir}/libdirac_decoder.so.0*

%files -n libdirac_encoder0
%{_libdir}/libdirac_encoder.so.0*

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/%{name}

%changelog
* Tue Jul  4 2017 tchvatal@suse.com
- Cleanu pwith spec-cleaner
- Switch to upstream tarball instead of repacking
- Update dependencies to match reality
- Explicitely enable configuration switches
- Disable docu building as they are kinda empty unless we would
  add latex and dot
* Tue May 26 2015 jkeil@suse.com
- Add baselibs.conf as Source
* Sun Apr 12 2015 plinnell@opensuse.org
- added existing baselibs.conf to fix build
* Sat Apr  4 2015 dmueller@suse.com
- remove unneeded texlive-latex dependency
* Sat Dec  7 2013 matz@suse.de
- Don't buildrequire valgrind-devel anywhere, it's unused.
* Thu Dec 20 2012 ro@suse.de
- buildrequire pkg-config regardless of build-architecture
* Fri Dec  9 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
- Add dirac-devel to baselibs
* Thu Apr 14 2011 toddrme2178@gmail.com
- added 32bit compatibility libraries
* Mon May 24 2010 davejplater@gmail.com
- Split off doc subpackage
* Mon May 24 2010 davejplater@gmail.com
- Added Provides: and Obsoletes: for packman libdirac-devel
- Included patch from dirac git to fix uninitialised memory read
  that causes the encoder to crash when using non-overlapping blocks.
* Sun May  9 2010 davejplater@gmail.com
- Fixed factory build with patch from git dirac-1.0.2-gcc45.patch
* Fri Dec 18 2009 jengelh@medozas.de
- exclude valgrind-devel on SPARC
* Sun Jul 12 2009 coolo@novell.com
- fix build in disabling as-needed
* Wed Jul  1 2009 sbrabec@suse.cz
- Updated to version 1.0.2:
  * minor release complying with the latest Dirac Bytestream
    Specification 2.2.3.
  * Improved compression performance for small picture sizes.
  * Improved compression performance at low bit-rates.
  * Included macros to check the API version.
  * Improved motion estimation.
  * New 422 <-> 420 conversion utilities for interlaced video.
  * New functionality added to encoder API.
  * Fixed bugs in handling DC subband.
* Wed Apr 29 2009 sbrabec@suse.cz
- Worked around internal compiler error on 11.0-x86_64.
* Tue Nov 25 2008 ro@suse.de
- do not buildrequire valgrind on ia64 s390 s390x
  (does not exist on these platforms)
* Thu Nov  6 2008 sbrabec@suse.cz
- New SuSE package (bnc#441855).
